@@ -1,76 +1,11 @@
 package AxKit::App::TABOO;
 
-our $VERSION = '0.39_2';
-
 use 5.7.3;
 use strict;
 use warnings;
 
-use Session;
-use Apache;
-use Apache::Cookie;
-use Apache::Request;
-use AxKit;
+our $VERSION = '0.086_1';
 
-sub session_config {
-  my $r = shift;
-  my $prefix = $r->dir_config( 'TABOOPrefix') || 'TABOO';
-  my %session_config = (
-			Store     => $r->dir_config( $prefix . 'DataStore' ) || 'DB_File',
-			Lock      => $r->dir_config( $prefix . 'Lock' ) || 'Null',
-			Generate  => $r->dir_config( $prefix . 'Generate' ) || 'MD5',
-			Serialize => $r->dir_config( $prefix . 'Serialize' ) || 'Storable'
-		       );
-   
-  # When using Postgres, a different default is needed.  
-  if ($session_config{'Store'} eq 'Postgres') {
-    $session_config{'Commit'} = 1;
-    $session_config{'Serialize'} = $r->dir_config( $prefix . 'Serialize' ) || 'Base64'
-  }
-
-  
-  # Load session-type specific parameters, comma-separated, name => value pairs
-  foreach my $arg ( split( /\s*,\s*/, $r->dir_config($prefix . 'Args'))) {
-    my ($key, $value) = split( /\s*=>\s*/, $arg );
-    $session_config{$key} = $value;
-  }
-
-  return %session_config;
-}
-
-sub session {
-  my $r = shift;
-  my $req = Apache::Request->instance($r);
-  my $vid = $req->param('VID');
-  unless ($vid) { # Then look in the cookie
-    my $cookies = Apache::Cookie->fetch;
-    my $tmp = $cookies->{'VID'};
-    return undef unless defined($tmp);
-    $vid = $tmp->value;
-    return undef unless ($vid); # No session key
-  }
-  AxKit::Debug(9, "User's visitor ID: $vid");
-  return new Session $vid, session_config($r);
-}
-    
-
-sub authlevel {
-  my $session = shift;
-  if (defined($session)) {
-    return $session->get('authlevel');
-  } else {
-    return 0;
-  }
-}
-
-sub loggedin {
-  my $session = shift;
-  if (defined($session)) {
-    return $session->get('loggedin');
-  } else {
-    return 'guest';
-  }
-}
 
 1;
 __END__
@@ -82,20 +17,21 @@ AxKit::App::TABOO - Object Oriented Publishing Framework for AxKit
 
 =head1 INTRODUCTION
 
+There is no code in this file. It may be some day, but for now, it is
+a placeholder, but one where it is convenient to say what this is, and
+my design philosophy for it. 
+
 AxKit::App::TABOO is a object oriented approach to creating a
 publishing system on the top of AxKit, the XML Application Server. 
 The two O's thus stands for Object Oriented, AB for AxKit-Based. 
 I don't know what the T stands for yet, suggestions are welcome! 
 
-This file holds only a few session and authentication functions, that
-I didn't quite knew where to put. This may change.
-
 
 =head1 DESIGN PHILOSOPHY
 
 There are three main ideas that forms the basis for TABOO:
 
-=over
+=over 
 
 =item 1. The data should be abstracted to objects so that the AxKit
 things never have to deal with where and how the data are stored. 
@@ -149,34 +85,27 @@ subclasses of it, some of which is again subclassed. There are too
 many to list.  They provide an abstraction layer that can manage the
 data for each of the types. They can load data from a data storage,
 currently a PostgreSQL data base, and they can write their data as
-XML, and write it back to the database. There are also Plural
+XML, and write it back to the database. There are now also Plural
 subclasses, built on the L<AxKit::App::TABOO::Data::Plurals> base
 class. These classes makes it easier to work on more than one of the
 above objects at a time, something that's often necessary. It also
 provides some containment of complexity, taking worries off of your
 head!
 
-Then, there are three working AxKit Providers:
-L<AxKit::App::TABOO::Provider::News>,
-L<AxKit::App::TABOO::Provider::NewsList> and
-L<AxKit::App::TABOO::Provider::Classification>, that makes use of the
-above subclasses, especially Story and Comment in the first case, the
-Stories in the second and a combination of those, Categories and
-Articles in the last. The first provider creates a page containing an
+Then, there are two AxKit Providers:
+L<AxKit::App::TABOO::Provider::News> and
+L<AxKit::App::TABOO::Provider::NewsList>, that makes use of the above
+subclasses, especially Story and Comment in the first case and the
+Stories in the second. The first provider creates a page containing an
 editor-reviewed story and user-submitted comments. The second makes
-lists of stories. The third creates lists of content based on
-categories. By simply manipulating the URI in easy-to-understand ways,
-you can load just the story, view the comments, separately, in a list
-or as a thread, or get simple lists or good overviews of stories, or
-lists of articles and stories in a category.
+lists of stories. By simply manipulating the URI in easy-to-understand
+ways, you can load just the story, view the comments, separately, in a
+list or as a thread, or get simple lists or good overviews of stories.
 
-Currently, it supplies six Taglibs,
+Currently, it supplies three Taglibs,
 L<User|AxKit::App::TABOO::XSP::User>,
-L<Story|AxKit::App::TABOO::XSP::Story>,
-L<Comment|AxKit::App::TABOO::XSP::Comment>,
-L<Comment|AxKit::App::TABOO::XSP::Articles>,
-L<Category|AxKit::App::TABOO::XSP::Category> and
-L<Category|AxKit::App::TABOO::XSP::Language>. These taglibs provide
+L<Story|AxKit::App::TABOO::XSP::Story> and
+L<Category|AxKit::App::TABOO::XSP::Category>. These taglibs provide
 several tags that you may use interface with the Data objects.
 
 There is quite a lot of XSP and XSLT now that allows you to enter and edit
@@ -184,27 +113,14 @@ stories and TABOO is nearly useable as a news-site management framework.
 
 Furthermore, there is also some user-management code, including
 authentication and authorization, to allow adding new users and
-editing the information of existing users. Important in this respect
-are L<AxKit::App::TABOO::Handler::Login> and
-L<AxKit::App::TABOO::AddXSLParams::Session> and handle the
-authentication and add session information to XSLT.
-
-It allows attaching comments to the news stories and any comment can
-simply get a C</respond> appended on its URI to allow for entering a
-response to it, and this is also easily done through links. It needs a
-bit more polish, though.
+editing the information of existing users.
 
 It can also format user-entered text with L<Formatter::HTML::Textile>.
 
 It also has some code for i18n, consisting of stylesheets that can
 take all strings of text from a separate XML file and insert them in
-the final product. This makes it easy to provide many translations
-with TABOO, allthough a real multilingual site is not yet supported.
-
-Pionered in 0.2 is the first code to manage more static articles,
-typically background articles with rich metadata. Content can be
-displayed, and that's pretty robust. Entering articles also works, but
-they cannot be edited yet.
+the final product. This will make it easy to provide many translations
+with TABOO, but it needs elaboration, which is next on the TODO list.
 
 =head1 CONFIGURATION EXAMPLE
 
@@ -225,6 +141,7 @@ separate username and password on a databse, and use different
 databases for different virtual hosts. A combination of C<DBI_DSN>,
 C<PGUSER> and C<PGPASSWORD> environment variables will achieve this.
 
+
   # \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
   # The below directives are common for all virtual hosts, if you run such
 
@@ -234,23 +151,18 @@ C<PGUSER> and C<PGPASSWORD> environment variables will achieve this.
 
   RewriteRule ^/user/([^/]+)$ /user/submit/user.xsp?username=$1
 
-  RewriteRule ^/user/submit/$ /user/submit/user.xsp
+  RewriteRule ^/user/submit/$ /user/submit/user.xsp 
   RewriteRule ^/user/submit/new$ /user/submit/new.xsp
 
-  RewriteRule ^/news/([^/]+)/([^/]+)/comment(/?.*)/respond$ /news/comment.xsp?sectionid=$1&storyname=$2&parentcpath=$3
-  RewriteRule ^/news/([^/]+)/([^/]+)/edit$ /news/submit.xsp?sectionid=$1&storyname=$2&edit=true
-
-  RewriteRule ^/articles/([^/]+)/([^/]+)$ /articles/provider.xsp?primcat=$1&filename=$2
-
   RewriteRule ^/$ /index.xsp
 
   # This may be needed on some setups
   DirectoryIndex index.xsp index.xml
 
 
-  # Some stuff should not be seen by AxKit.
-  <Location ~ "/css/|favicon.ico">
-    SetHandler default-handler
+  # Stuff in the /css/ directory should not be seen by AxKit.
+  <Location /css/>
+    SetHandler default-handler 
   </Location>
 
 
@@ -267,58 +179,41 @@ C<PGUSER> and C<PGPASSWORD> environment variables will achieve this.
   AxAddPlugin Apache::AxKit::Plugin::Passthru
 
   AxAddPlugin Apache::AxKit::Plugin::AddXSLParams::Request
-  PerlSetVar AxAddXSLParamGroups "Request-Common HTTPHeaders"
+  PerlSetVar AxAddXSLParamGroups "HTTPHeaders"
 
   # If you want a different language than English, you need to
   # translate i18n.en.xml and replace nb with your language
   # code. These two directives are optional, you don't need any if you
   # want English.
-  AxAddPlugin Apache::AxKit::Plugin::Param::Expr
-  PerlAddVar AxParamExpr neg.lang '"nb"'
+  AxAddPlugin Apache::AxKit::Plugin::XSLTParam
+  PerlAddVar XSLTParam neg.lang '"nb"'
 
-  AxAddPlugin AxKit::App::TABOO::AddXSLParams::Session
 
+  # Authentication
+  PerlModule Apache::AxKit::Plugin::BasicAuth
+  AxAddPlugin Apache::AxKit::Plugin::BasicSession
+  AxAddPlugin Apache::AxKit::Plugin::AddXSLParams::BasicSession
 
   # TABOO XSPs
   AxAddXSPTaglib AxKit::App::TABOO::XSP::User
   AxAddXSPTaglib AxKit::App::TABOO::XSP::Story
   AxAddXSPTaglib AxKit::App::TABOO::XSP::Category
-  AxAddXSPTaglib AxKit::App::TABOO::XSP::Comment
-#  AxAddXSPTaglib AxKit::App::TABOO::XSP::Article
-  AxAddXSPTaglib AxKit::App::TABOO::XSP::Language
-
-
-
 
   # Other XSPs
-
+  AxAddXSPTaglib AxKit::XSP::BasicAuth
+  AxAddXSPTaglib AxKit::XSP::BasicSession
   AxAddXSPTaglib AxKit::XSP::QueryParam
   AxAddXSPTaglib AxKit::XSP::Sendmail
 
-  PerlAddVar AxParamExpr cats.prefix '"/cats/"'
-
-  PerlModule AxKit::App::TABOO::Handler::Login
-  <Location /login>
-     SetHandler perl-script
-     PerlHandler AxKit::App::TABOO::Handler::Login
-     PerlSendHeader On
-  </Location>
-
-
-  <Location /cats/>
-  	PerlHandler AxKit
-        AxContentProvider AxKit::App::TABOO::Provider::Classification
-  </Location>
-
 
   # Providers for News, depending somewhat on the paths.
 
-  <LocationMatch ^/news/[^(respond$)]*>
-  	PerlHandler AxKit
+  <Location /news/>
+        PerlHandler AxKit
         AxContentProvider AxKit::App::TABOO::Provider::NewsList
-    	PerlSetVar TABOOListDefaultRecords 20
-    	PerlSetVar TABOOListMaxRecords 200
-  </LocationMatch>
+        PerlSetVar TABOOListDefaultRecords 20
+        PerlSetVar TABOOListMaxRecords 200
+  </Location>
 
 
   <Location /news/submit>
@@ -333,12 +228,6 @@ C<PGUSER> and C<PGPASSWORD> environment variables will achieve this.
   </LocationMatch>
 
 
-  <LocationMatch ^/news/.+/(respond|edit)$>
-   	PerlHandler AxKit
-  	AxContentProvider Apache::AxKit::Provider::File
-  </LocationMatch>
-
-
   # ////////////////////////////////
 
 
@@ -370,16 +259,20 @@ C<PGUSER> and C<PGPASSWORD> environment variables will achieve this.
   # Aliases, rather than files have a full filesystem path. 
   # That's rather evil...
   Alias /news/submit /var/www/news/submit.xsp 
-  Alias /categories/submit /var/www/categories/submit.xsp 
-
-  Alias /articles/submit /var/www/articles/submit.xsp 
-  Alias /articles/edit /var/www/articles/edit.xsp 
+  Alias /login /var/www/login.xsp
 
 
   # Authentication and authorization stuff
+  <Location />
+      AuthType Apache::AxKit::Plugin::BasicAuth
+      AuthName TABOODemo
+  </Location>
+
+  PerlSetVar TABOODemoURIToken SID
+  PerlSetVar TABOODemoDataStore DB_File
+  PerlSetVar TABOODemoArgs      "FileName => /tmp/taboodemo-session"
+  PerlSetVar TABOODemoLoginScript /login.xsp
 
-  PerlSetVar TABOODataStore DB_File
-  PerlSetVar TABOOArgs      "FileName => /tmp/taboodemo-session"
 
   # /////////////////////////////
 
@@ -394,22 +287,22 @@ feel good, but it was the way I it working...
 =head1 TODO
 
 A lot. Because this is a POD, I'm stopping with my lofty visions here
-(there's more of that in the README). This is the first beta of TABOO,
-and it seems to do what it is intended to, namely be a site where
-multiple users can post news stories, and comment them. That's
-something that has been done before, of course, but not within the
-design goals stated above.
+(there's more of that in the README). It is still in sort of an alpha
+state, but Real Soon Now it should be a beta useful enough to put on a
+test website and have random folks playing with.
 
-The Article code needs work still, manipulate articles better, but I
-have actually put what I have in production, and it works!
 
-Also, I need some kind of gallery code soonish.
+Allthough it is not included in the present distro, I have also mostly
+finished an Article Provider, which is intended to be used for more
+static content. However, most attention will be given to the News
+part, because that is the first thing that will give people something
+to play with.
 
 Finally note that things that are there are B<not stable>! Names may
 change, parameters may be different, and I may decide to do things
 differently, depending on how this projects evolves, what new things I
 learn (this is very much a learning process for me), and what kind of
-feedback hackers provide.
+feedback hackers provide. 
 
 TABOO also has had some code for a webshop, but since it has fallen
 behind the rest of the development, it has been removed from the
@@ -420,24 +313,23 @@ the rest of framework. TABOO will make a great webshop platform...!
 
 =head1 SUPPORT
 
-There is now a taboo-dev mailing list that can be subscribed to at
+There is now a taboo-dev mailing list that can be subscribed to at 
 http://lists.kjernsmo.net/mailman/listinfo/taboo-dev
 
 =head1 BUGS
 
+This release is the first to offer virtual host capacity. It has not
+been very extensively tested, but in the tests I have done, it works
+well.
+
+In this release L<AxKit::App::TABOO::Data::Comment> doesn't work. It
+needs to be reworked to support the new Plurals concept, but that's
+not at the top of my list for the moment.
+
+
 There are surely some... Please report any you find through CPAN RT:
 http://rt.cpan.org/NoAuth/Bugs.html?Dist=AxKit-App-TABOO .
 
-=head1 SUBVERSION REPOSITORY
-
-TABOO is currently maintained in a Subversion repository. The trunk
-can be checked out anonymously using e.g.:
-
-  svn checkout http://svn.kjernsmo.net/TABOO/trunk TABOO  
-
-It is also available using the svn schema and svn+ssh for committers.
-
-
 =head1 AUTHOR
 
 Kjetil Kjernsmo, E<lt>kjetilk@cpan.orgE<gt>
@@ -448,9 +340,7 @@ L<AxKit>, L<AxKit::App::TABOO::Data>, L<AxKit::App::TABOO::Provider::News>.
 
 =head1 COPYRIGHT AND LICENCE
 
-Copyright (c) 2003-2006 Kjetil Kjernsmo. This program is free
-software; you can redistribute it and/or modify it under the same
-terms as Perl itself.
+Copyright (c) 2003-2004 Kjetil Kjernsmo. Some rights reserved. This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself. 
 
 
 =cut
